import java.io.File;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.types.Parameter;
import org.apache.tools.ant.types.selectors.BaseExtendSelector;

/**
 * Split a fileset into the given number of parts.
 * @author KoR
 */
public final class DividingSelector extends BaseExtendSelector
{

   private int counter;
   /**
    * Number of total parts to split.
    */
   private int divisor;
   /**
    * Current part to accept.
    */
   private int part;

   public void setParameters(Parameter[] pParameters)
   {
      super.setParameters(pParameters);
      for (int j = 0; j < pParameters.length; j++)
      {
         Parameter p = pParameters[j];
         if ("divisor".equalsIgnoreCase(p.getName()))
         {
            divisor = Integer.parseInt(p.getValue());
         }
         else if ("part".equalsIgnoreCase(p.getName()))
         {
            part = Integer.parseInt(p.getValue());
         }
         else
         {
            throw new BuildException("unsupported parameter " + p.getName() + " with value " + p.getValue());
         }
      }
   }

   public void verifySettings()
   {
      super.verifySettings();
      if (divisor <= 0 || part <= 0)
      {
         throw new BuildException("parameter part or divisor not set");
      }
      if (part > divisor)
      {
         throw new BuildException("parameter part must be <= divisor");
      }
   }

   public boolean isSelected(File pBaseDir, String pRelative, File pFullPath)
   {
      counter = counter % divisor + 1;
      return counter == part;
   }
}
